@@ -35,6 +35,7 @@ __all__ = (
     "ListScramSecretsPaginatorName",
     "NodeTypeType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -344,3 +345,12 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "list_cluster_operations",
+    "list_clusters",
+    "list_configuration_revisions",
+    "list_configurations",
+    "list_kafka_versions",
+    "list_nodes",
+    "list_scram_secrets",
+]
